@@ -429,7 +429,6 @@ read_config(char *file, struct cfentry *cfe, int count, void *data)
             error++;
         }
     }
-
     fclose(fp);
 
     for (i = 0; i < count; i++) {
@@ -608,6 +607,30 @@ is_ipaddr(char *str)
     return (NULL);
 }
 
+/*
+ * is_plus
+ *
+ * ǽ
+ *      ݡֹΥå065535ˡ
+ *
+ * 
+ *      int value      å
+ *
+ * ֤
+ *      NULL                  
+ *      ERR_CONF_PLUS         顼å
+ *
+ */
+char *
+is_plus(int value)
+{
+    if (value <= 0) {
+        return (ERR_CONF_PLUS);
+    }
+
+    return (NULL);
+}
+
 /*
  * is_port
  *
