@@ -123,6 +123,7 @@ search_rcptstr_bdb(DB *rcpt_dbp, const char *rcptdbpath, char *rcptaddr, char *s
             passwd = NULL;
 
             if (add_enclist(&passlist, searchstr, rcptaddr, tmppass) != 0) {
+                free(noenc_searchstr);
                 return MALLOC_ERROR;
             }
             DEBUGLOG("Add keyword to passlist structure.(%s)", searchstr);
@@ -131,6 +132,7 @@ search_rcptstr_bdb(DB *rcpt_dbp, const char *rcptdbpath, char *rcptaddr, char *s
         } else {
             /* Add rdmpasslist list */
             if (add_enclist(&rdmpasslist, OTHERKEYWORD, rcptaddr, onetime_pass) != 0) {
+                free(noenc_searchstr);
                 return MALLOC_ERROR;
             }
             DEBUGLOG("Add keyword to rdmpasslist structure.(%s)", searchstr);
@@ -192,7 +194,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
     int default_policy = NOT_ENC;
     int user_policy = NOT_ENC;
     char *rcptaddr = NULL;
-    int rcptaddrlen = 0;
+    //int rcptaddrlen = 0;
     int pass_len = cfg->cf_passwordlength;
     int defalt_pass_len = 0;
     struct search_res res;
@@ -248,7 +250,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
 
     for (i = 0; (rcptlist + i)->rcpt_addr != NULL; i++) {
         rcptaddr = (rcptlist + i)->rcpt_addr;
-        rcptaddrlen = (rcptlist + i)->rcpt_addr_len;
+        //rcptaddrlen = (rcptlist + i)->rcpt_addr_len;
         DEBUGLOG("Check Rcpt Addr.(%s)", rcptaddr);
 
         /* Berkeleydb check */
@@ -322,7 +324,7 @@ search_rcptaddr_delmode(struct config *cfg, struct rcptaddr *rcptlist, struct rc
     int enc_status = NOT_ENC; 
     int default_policy = NOT_ENC;
     char *rcptaddr = NULL;
-    int rcptaddrlen = 0;
+    //int rcptaddrlen = 0;
     int pass_len = 0;
     int defalt_pass_len = 0;
     struct search_res res;
@@ -342,10 +344,17 @@ search_rcptaddr_delmode(struct config *cfg, struct rcptaddr *rcptlist, struct rc
 
 
     /* default policy set */
-    if ((cfg->cf_defaultdeletepolicy[0] == 'Y') || (cfg->cf_defaultdeletepolicy[0] == 'y')) {
-        default_policy = ENC;
+    if (ismode_delete) {
+        if ((cfg->cf_defaultdeletepolicy[0] == 'Y') || (cfg->cf_defaultdeletepolicy[0] == 'y')) {
+            default_policy = ENC;
+        }
+    } else if (ismode_harmless) {
+        if ((cfg->cf_defaultsendercheck[0] == 'Y') || (cfg->cf_defaultsendercheck[0] == 'y')) {
+            default_policy = ENC;
+        }
     }
 
+
     /* rcptdb open */
     ret = db_open(&res.rcpt_dbp, cfg->cf_rcptdbpath, cfg->cf_rcptdbtype);
     if (ret == DB_ERROR) {
@@ -355,7 +364,7 @@ search_rcptaddr_delmode(struct config *cfg, struct rcptaddr *rcptlist, struct rc
 
     for (i = 0; (rcptlist + i)->rcpt_addr != NULL; i++) {
         rcptaddr = (rcptlist + i)->rcpt_addr;
-        rcptaddrlen = (rcptlist + i)->rcpt_addr_len;
+        //rcptaddrlen = (rcptlist + i)->rcpt_addr_len;
         DEBUGLOG("Check Rcpt Addr.(%s)", rcptaddr);
 
         /* Berkeleydb check */
@@ -674,18 +683,30 @@ add_enclist(struct rcptinfo ***head, char *keyword, char *addr, char *passwd)
     }
     memset(rcptinfo, 0, sizeof *rcptinfo);
 
-    /* not allocate memory */
-    rcptinfo->keyword = keyword;
+    /* Copy keyword to rcptinfo struction 
+     * because the keyword will be freed 
+     * when keyword is equivalent to the searchaddr
+     * which is allocated in the function search_rcptaddr_bdb(). */
+    rcptinfo->keyword = strdup(keyword);
+    if (rcptinfo->keyword == NULL) {
+        free(rcptinfo);
+        log(ERR_MEMORY_ALLOCATE, "add_enclist", "rcptinfo->keyword", strerror(errno));
+        return -1;
+    }
     rcptinfo->keyword_len = strlen(keyword);
 
     /* allocate memory */
     rcptinfo->passwd = strdup(passwd);
     if (rcptinfo->passwd == NULL) {
+        free(rcptinfo->keyword);
+        free(rcptinfo);
         log(ERR_MEMORY_ALLOCATE, "add_enclist", "rcptinfo->passwd", strerror(errno));
         return -1;
     }
 
     if (push_rcptlist(&(rcptinfo->rcptlist), addr) != 0) {
+        free(rcptinfo->keyword);
+        free(rcptinfo->passwd);
         free(rcptinfo);
         return -1;
     }
