@@ -37,6 +37,8 @@
 #include <dirent.h>
 #include <pthread.h>
 #include <libdgstr.h>
+#include <fcntl.h>
+#include <fcntl.h>
 
 #include "mailzip_config.h"
 #include "mailsave.h"
@@ -216,7 +218,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 {
     struct mailzip mz;
     struct rcptinfo *p;
-    int i, ret;
+    int i, ret, chk_replace, chk_replace_noconv;
     char *temp = NULL, *notify_message, *rcptaddr, *confirmation_message;
     char *org_p;
 
@@ -264,13 +266,26 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 	        temp = tmpl_init();
 
 
-	        if (tmpl_tag_replace(temp, mz, p, from, &confirmation_message) != 0){
+	        chk_replace = tmpl_tag_replace(temp, mz, p, from, &confirmation_message);
+            switch(chk_replace) {
+                case ERROR:
                     p->passwd = org_p;	/* restore original password */
-	            tmpl_release(temp);
-	            mailzip_clean(mz);
-	            return ZIP_CONVERT_FAILED;
+                    tmpl_release(temp);
+                    mailzip_clean(mz);
+                    return ZIP_CONVERT_FAILED;
+                case CONVERT_ERROR:
+                    // replace not converted string
+                    chk_replace_noconv = tmpl_tag_replace_noconv(mz, p, from,
+                                                                 &confirmation_message,
+                                                                 cfg->cf_errmsgtemplatepath);
+
+                    if (chk_replace_noconv == ERROR) {
+                        tmpl_release(temp);
+                        mailzip_clean(mz);
+                        return ZIP_CONVERT_FAILED;
+                    }
 	        }
-                p->passwd = org_p;	/* restore original password */
+            p->passwd = org_p;	/* restore original password */
 	        tmpl_release(temp);
 
                 // set header field "References"
@@ -328,11 +343,24 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 	}
 
 	temp = tmpl_init();
-	if (tmpl_tag_replace(temp, mz, rdmpasslist, from, &notify_message) != 0){
-	    tmpl_release(temp);
-	    mailzip_clean(mz);
-	    return ZIP_CONVERT_FAILED;
-	}
+
+    chk_replace = tmpl_tag_replace(temp, mz, rdmpasslist, from, &notify_message);
+    switch(chk_replace) {
+        case ERROR:
+            tmpl_release(temp);
+            mailzip_clean(mz);
+            return ZIP_CONVERT_FAILED;
+        case CONVERT_ERROR:
+            // replace before convert string
+            chk_replace_noconv = tmpl_tag_replace_noconv(mz, rdmpasslist, from,
+                                                         &notify_message, cfg->cf_errmsgtemplatepath);
+
+            if (chk_replace_noconv == ERROR) {
+                tmpl_release(temp);
+                mailzip_clean(mz);
+                return ZIP_CONVERT_FAILED;
+            }
+    }
 	tmpl_release(temp);
 
         // set header field "references"
